@@ -13,7 +13,7 @@ class InputCaptureDialog : public QuickDialog
 {
     Q_OBJECT
 public:
-    InputCaptureDialog(const QString &appId, InputCapturePortal::Capabilities capabilties, QObject *parent = nullptr);
+    InputCaptureDialog(const QString &appId, InputCapturePortal::Capabilities capabilities, QObject *parent = nullptr);
 };
 
 #endif
