@@ -11,12 +11,8 @@
 
 #include "quickdialog.h"
 
-namespace Ui
-{
-class UserInfoDialog;
-}
-
 class OrgFreedesktopAccountsUserInterface;
+struct UserDetails;
 
 class UserInfoDialog : public QuickDialog
 {
@@ -24,13 +20,14 @@ class UserInfoDialog : public QuickDialog
 public:
     explicit UserInfoDialog(const QString &reason, const QString &app_id, QObject *parent = nullptr);
     ~UserInfoDialog() override;
+    Q_DISABLE_COPY_MOVE(UserInfoDialog)
 
-    QString id() const;
-    QString name() const;
-    QString image() const;
+    [[nodiscard]] QString id() const;
+    [[nodiscard]] QString name() const;
+    [[nodiscard]] QString image() const;
 
 private:
-    OrgFreedesktopAccountsUserInterface *m_userInterface;
+    std::unique_ptr<UserDetails> m_userDetails;
 };
 
 #endif // XDG_DESKTOP_PORTAL_KDE_USERINFO_DIALOG_H
